/* -----------------------------------------------------------
 *
 *  main.c -- Read and Write from the MX4cK built in EEPROM (32K)
 *   and Write using fast mode to the DAC
 *   both of these component are on the I2C serial bus
 *
 *  The I2C read and write routines are not thread safe. If used in
 *  a multi-threaded environment you will need to add safe guards to
 *  ensure multiple copies of the routines are not being run at once -
 *  such as a critical sections or mutex.
 *
 *
 *
 *  Mason, Seattle U. 2013
 * ------------------------------------------------------------ */

#include <plib.h>
#include "MX4cKsetup.h"
#include "MX4cKsettings.h"
#include "I2C/I2C_DACEEPROM.h"

int main(void) {
    // place to store data sent to/from EEPROM
    UINT8 inData[80];
    UINT8 outData[80];
    BOOL success;

    int i;

    // populate dummy data to write to EEPROM
    strcpy(inData, "I'm reading this poem from inside a lion, and its rather dark in here.");

    for (i = 0; i < 80; i++)
        outData[i] = 0;

    // The I2C shares pins with other digital IO
    // becareful when using I2C to avoid using these IO pins
    // see the MX4cK pin out.
    I2C_Initialize();

    // write 6 bytes to location   0x0540
    success = EEPROMI2C_StoreData(inData, 0x0540, 70);

    // read 6 bytes from address 0x0540
    success = EEPROMI2C_ReadData(outData, 0x0540, 70);


    // write data to the DAC

    // send a stream of value to the DAC.  Can use this method to create a waveform output
    // First call to SetValue must set second parameter to TRUE.  This sends the address of the DAC
    // along with the data
    DACI2C_SetValue(0, TRUE);


    // now can keep sending data to the DAC
    for (i = 1; i < 0x0FFF; i++) {
        DACI2C_SetValue(i, FALSE);
        //   for (j=0;j<1000;j++){
        //       asm("nop");  // delay is needed.  A better solution would be to use a timer of RTOS so you can
        // do something else while waiting
        //   }
    }

    // call stopTransfer when done talking to the DAC
    I2C_StopTransfer();
    while (1);
}